BuiltinWidgetSideEffects extension
A collection of the builtin WidgetSideEffects.
Methods
-
animationController(
{Duration? duration, Duration? reverseDuration, String? debugLabel, double initialValue = 0, double lowerBound = 0, double upperBound = 1, TickerProvider? vsync, AnimationBehavior animationBehavior = AnimationBehavior.normal}) → AnimationController -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Provides a way to easily get a copy of an AnimationController. -
api(
) → WidgetSideEffectApi -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
The WidgetSideEffectApi backing this WidgetSideEffectRegistrar. -
automaticKeepAlive(
{bool keepAlive = true}) → void -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Prevents the associated RearchConsumer from being disposed when it normally would be by its lazy list container (such as in a ListView). -
context(
) → BuildContext -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
The BuildContext associated with this WidgetSideEffectRegistrar. -
focusNode(
{String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true, bool descendantsAreTraversable = true}) → FocusNode -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Provides a way to easily get a copy of a FocusNode. -
focusScopeNode(
{String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, TraversalEdgeBehavior traversalEdgeBehavior = TraversalEdgeBehavior.closedLoop}) → FocusScopeNode -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Provides a way to easily get a copy of a FocusScopeNode. -
pageController(
{int initialPage = 0, bool keepPage = true, double viewportFraction = 1.0, void onAttach(ScrollPosition)?, void onDetach(ScrollPosition)?}) → PageController -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Provides a way to easily get a copy of a PageController. -
singleTickerProvider(
) → TickerProvider -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Creates a single use TickerProvider. Used by animationController whenvsyncis not set. -
textEditingController(
{String? initialText}) → TextEditingController -
Available on WidgetSideEffectRegistrar, provided by the BuiltinWidgetSideEffects extension
Provides a way to easily get a copy of a TextEditingController.