automaticKeepAlive method
Prevents the associated RearchConsumer from being disposed when it normally would be by its lazy list container (such as in a ListView).
Acts similar to AutomaticKeepAlive.
When using automaticKeepAlive, you must use it in a new RearchConsumer that is a child of the container; otherwise, the widget might still be disposed.
Implementation
void automaticKeepAlive({bool keepAlive = true}) =>
_automaticKeepAlive(this, keepAlive: keepAlive);